@@ -1,7 +1,6 @@
 """
     Defining API Versions
 """
+from . import v1
 
-from . import v1beta
-
-__all__ = [v1beta]
+__all__ = [v1]
