@@ -35,3 +35,15 @@ class AccountingExports(ListResources, ListAllResources, PostResources, GetResou
             api_url=AccountingExports.BULK_CREATE_ACCOUNTING_EXPORT_LINEITEMS,
             payload=payload
         )
+
+    def get_accounting_export_lineitems(self, query_params):
+        return self.api.make_get_request(
+            api_url=AccountingExports.ACCOUNTING_EXPORT_LINEITEMS,
+            query_params=query_params
+        )
+
+    def get_accounting_exports(self, query_params):
+        return self.api.make_get_request(
+            api_url=AccountingExports.ACCOUNTING_EXPORTS,
+            query_params=query_params
+        )
