@@ -1,13 +1,13 @@
 """
 V1 Admin Expense Fields
 """
-
 from ....internals.list_all_resources import ListAllResources
 from ....internals.list_resources import ListResources
 from ....internals.post_resources import PostResources
+from ....internals.get_resources import GetResources
 
 
-class ExpenseFields(ListResources, ListAllResources, PostResources):
+class ExpenseFields(ListResources, ListAllResources, PostResources, GetResources):
     """Class for Expense Fields APIs."""
 
     EXPENSE_FIELDS = '/expense_fields'
