@@ -5,9 +5,9 @@ V1 Admin Projects
 from ....internals.list_resources import ListResources
 from ....internals.list_all_resources import ListAllResources
 from ....internals.post_resources import PostResources
+from ....internals.post_bulk_resources import PostBulkResources
 
-
-class Projects(ListResources, ListAllResources, PostResources):
+class Projects(ListResources, ListAllResources, PostResources, PostBulkResources):
     """Class for Projects APIs."""
 
     PROJECTS = '/projects'
