@@ -2,13 +2,15 @@
 V1 Admin Tax Groups
 """
 
+from typing import Dict, List
+from fyle.platform.internals.post_bulk_resources import PostBulkResources
 from ....internals.get_resources import GetResources
 from ....internals.list_all_resources import ListAllResources
 from ....internals.list_resources import ListResources
 from ....internals.post_resources import PostResources
 
 
-class TaxGroups(ListResources, ListAllResources, PostResources, GetResources):
+class TaxGroups(ListResources, ListAllResources, PostResources, GetResources, PostBulkResources):
     """Class for Tax Groups APIs."""
 
     TAX_GROUPS = '/tax_groups'
