@@ -2,6 +2,7 @@
     Define ApiBase class implementing API helper methods.
 """
 
+import logging
 import json
 
 from .decorators import retry
@@ -10,6 +11,8 @@ from .. import exceptions
 from ..globals.config import config
 
 
+logger = logging.getLogger(__name__)
+
 class ApiBase(Network):
     """The base class for all API classes."""
 
@@ -26,7 +29,7 @@ class ApiBase(Network):
             endpoint=endpoint
         )
 
-    @retry(n=3, backoff=5, exceptions=exceptions.InvalidTokenError)
+    @retry(n=3, backoff=5, exceptions=(exceptions.InvalidTokenError, exceptions.InternalServerError))
     def make_get_request(self, api_url, query_params=None):
         """Create a HTTP GET request.
         Parameters:
@@ -57,9 +60,11 @@ class ApiBase(Network):
         )
 
         if response.status_code == 200:
+            logger.debug('Response for get request for url: %s, %s', api_url, response.text)
             result = json.loads(response.text)
             return result
 
+        logger.info('Response for get request for url: %s, %s', api_url, response.text)
         ApiBase._assert_response(response)
 
     @retry(n=3, backoff=5, exceptions=exceptions.InvalidTokenError)
@@ -83,10 +88,14 @@ class ApiBase(Network):
             data=payload
         )
 
+        logger.debug('Payload for post request: %s', payload)
+
         if response.status_code == 200:
+            logger.debug('Response for post request: %s', response.text)
             result = json.loads(response.text)
             return result
-
+        
+        logger.info('Response for post request: %s', response.text)
         ApiBase._assert_response(response)
 
 
@@ -107,7 +116,7 @@ class ApiBase(Network):
         if response.status_code == 498:
             raise exceptions.ExpiredTokenError(
                 'Expired token, try to refresh it', response.text)
-        if response.status_code == 500:
+        if response.status_code >= 500:
             raise exceptions.InternalServerError(
                 'Internal server error', response.text)
         raise exceptions.PlatformError(
