@@ -4,6 +4,8 @@
 
 import time
 
+from functools import wraps
+
 from .auth import Auth
 from .. import exceptions as exc
 
@@ -19,17 +21,18 @@ def retry(n, backoff, exceptions):
     """
 
     def decorator(func):
+        @wraps(func)
         def new_fn(*args, **kwargs):
             attempt = 0
             while attempt < n:
                 try:
                     return func(*args, **kwargs)
-                except exceptions:
-                    if exc.InvalidTokenError in exceptions:
+                except exceptions as e:
+                    if isinstance(e, exc.InvalidTokenError):
                         Auth().update_access_token()
                     time.sleep(backoff)
                     attempt += 1
-            raise exc.RetryException('failed to execute %s despite retrying' % func)
+            raise exc.RetryException('failed to execute %s despite retrying' % func.__name__)
 
         return new_fn
 
